@@ -19,6 +19,7 @@
 
 #include "main.h"
 #include "webcam.h"
+#include "settings.h"
 
 
 #ifdef WITH_WEBCAM
@@ -27,7 +28,6 @@ extern char *video_base;
 #endif
 extern uint8_t  statistics;
 extern uint16_t http_port;
-extern uint8_t  statistics;
 extern uint8_t  max_fps;
 extern uint8_t  use_hard_timers;
 extern uint8_t  encoding;
@@ -48,7 +48,7 @@ usage()
   printf("Usage: " PACKAGE_NAME " [options]\n\n"
          "\t-a, --audio <file>\tSet audio file (sndfile plugin)\n"
          "\t-b, --basedir <path>\tSet base directory [" DEFAULT_PLUGINSDIR "]\n"
-         "\t-c, --config <file>\tSet configuration file [~/" KEYFILE "]\n"
+         "\t-c, --config <file>\tSet configuration file [~/." PACKAGE_NAME "/" JSON_SETTINGS "]\n"
          "\t-d, --datadir <path>\tSet data directory [" DEFAULT_DATADIR "]\n"
          "\t-f, --fullscreen\tSet fullscreen\n"
          "\t-h, --help\t\tDisplay this help\n"
@@ -60,8 +60,9 @@ usage()
          "\t-q, --quiet\t\tSuppress messages\n"
          "\t-r, --random <mode>\tSet auto-random mode\n"
          "\t-s, --soft-timers\tUse soft timers instead of the system clock\n"
-         "\t-t, --themes <themes>\tComma-separated list of themes to use [biniou]\n"
+         "\t-t, --themes <themes>\tComma-separated list of themes to use [biniou,covid-19,zebulon]\n"
          "\t-v, --version\t\tDisplay the version and exit\n"
+         "\t-w, --http-port\t\tWeb interface port [%d]\n"
 #ifndef FIXED
          "\t-x, --width <width>\tSet width [%d]\n"
          "\t-y, --height <height>\tSet height [%d]\n"
@@ -90,6 +91,7 @@ usage()
          "\n"
          , max_fps
          , pid_file
+         , http_port
 #ifndef FIXED
          , DEFAULT_WIDTH
          , DEFAULT_HEIGHT
@@ -176,9 +178,8 @@ getargs(int argc, char **argv)
         break;
 
       case 'c':
-        /* re-read configuration file */
-        set_configuration(optarg);
-        read_keyfile();
+        Settings_set_configuration_file(optarg);
+        Settings_load();
         break;
 
       case 'd':
@@ -262,10 +263,7 @@ getargs(int argc, char **argv)
         break;
 
       case 't':
-        if (NULL != themes) {
-          xfree(themes);
-        }
-        themes = strdup(optarg);
+        themes = optarg;
         VERBOSE(printf("[c] Using themes: %s\n", themes));
         break;
 
@@ -341,7 +339,9 @@ getargs(int argc, char **argv)
         if (desired_webcams <= MAX_CAMS) {
           VERBOSE(printf("[c] webcam: grabbing %d device%s\n", desired_webcams, (desired_webcams == 1 ? "": "s")));
         } else {
-          desired_webcams = 1;
+          if (desired_webcams) {
+            desired_webcams = 1;
+          }
         }
         break;
 
@@ -402,7 +402,7 @@ getargs(int argc, char **argv)
   }
 
   if (NULL == input_plugin) {
-    input_plugin = DEFAULT_INPUT_PLUGIN;
+    input_plugin = strdup(DEFAULT_INPUT_PLUGIN);
   } else if (is_equal(input_plugin, "NULL")) {
     input_plugin = NULL;
   }
@@ -413,10 +413,6 @@ getargs(int argc, char **argv)
     output_plugin = NULL;
   }
 
-  if (NULL == themes) {
-    themes = strdup("biniou");
-  }
-
 #ifdef WITH_WEBCAM
   if (NULL == video_base) {
     video_base = strdup(DEFAULT_VIDEO_DEVICE);
